pub type ConnectionResult<T> = Result<T, ConnectionError>;Expand description
Result type returned while opening or initializing a device connection.
Aliased Type
pub enum ConnectionResult<T> {
Ok(T),
Err(ConnectionError),
}pub type ConnectionResult<T> = Result<T, ConnectionError>;Result type returned while opening or initializing a device connection.
pub enum ConnectionResult<T> {
Ok(T),
Err(ConnectionError),
}